<h1 align="center">spx-color</h1>
<p align="center">A very Simple Module it help You to Use The Color Very easy!</p>

## Installation :
```
pip install spxcolor

```

### Example :
```
from spxcolor import *

print(Red + "Hello, World!")
 
# By Spyrx
```

### The Methods in Module :
```
* ~ ~ ~ ~ ~ ~ ~ Color ~ ~ ~ ~ ~ ~ ~ 
* Black 
* Red
* Green 
* Yellow
* Blue 
* Purple 
* Cyan 
* White 
* ~ ~ ~ ~ ~ ~ ~ Bold ~ ~ ~ ~ ~ ~ ~
* BoBlack
* BoRed 
* BoGreen
* BoYellow
* BoBlue
* BoPurple
* BoCyan
* BoWhite
* ~ ~ ~ ~ ~ ~ ~ Underline ~ ~ ~ ~ ~ ~ ~ 
* UnBlack
* UnRed
* UnGreen
* UnYellow
* UnBlue
* UnPurple
* UnCyan
* UnWhite
* ~ ~ ~ ~ ~ ~ ~ Background ~ ~ ~ ~ ~ ~ ~ 
* BaBlack
* BaRed
* BaGreen
* BaYellow
* BaBlue
* BaPurple
* BaCyan
* BaWhite
* ~ ~ ~ ~ ~ ~ ~  High Intensty ~ ~ ~ ~ ~ ~ ~
* IBlack
* IRed
* IGreen 
* IYellow
* IBlue
* IPurple
* ICyan
* IWhite
* ~ ~ ~ ~ ~ Bold High Intensty ~ ~ ~ ~ ~ ~ ~
* BIBlack
* BIRed
* BIGreen
* BIYellow
* BIBlue
* BIPurple
* BICyan
* BIWhite
* ~ ~ ~ ~ ~ ~ ~  High Intensty Background ~ ~ ~ ~ ~ ~ ~
* BaIBlack
* BaIRed
* BaIGreen
* BaIYellow
* BaIBlue
* BaIPurple
* BaICyan
* BaIWhite
```
